@@ -5,21 +5,23 @@ from rest_framework.permissions import IsAuthenticatedOrReadOnly
 
 from .models import Category
 from .serializers import CategorySerializer
-from rest_framework.filters import OrderingFilter
-from .filter import CategoryFilter
-from rest_framework import filters
-from django_filters.rest_framework.backends import DjangoFilterBackend
 
 
 class CategoryView(CustomModelViewSet, TreeAPIView):
     model_class = Category
     serializer_class = CategorySerializer
     pagination_class = None
-    filterset_class = CategoryFilter
-    filter_backends = [
-        DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter]
-    ordering_fields = '__all__'
     permission_classes = [IsAuthenticatedOrReadOnly]
+    filterset_fields = {
+        'category_type': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'title': {
+            'field_type': 'string',
+            'lookup_expr': '__icontains'
+        }
+    }
 
     @action(detail=False, methods=['post'], url_path='sort', url_name='sort')
     def sort(self, request, *args, **kwargs):
