@@ -48,7 +48,7 @@ class ChatConsumer(WebsocketConsumer):
             Event_chat_queryset = EventChat.objects.get(pk=_id)
             Event_chat_queryset.state = 1
             Event_chat_queryset.save()
-            data['event_chat_id'] = _id
+            data['chat_id'] = _id
             # Send message to room group
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
