@@ -10,8 +10,14 @@ class EventChatView(CustomModelViewSet, AllView):
     model_class = EventChat
     serializer_class = EventChatSerializer
     filterset_fields = {
-        'event_id': ['exact'],
-        'state': ['exact']
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'state': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
     }
 
     def perform_create(self, serializer):
