@@ -14,7 +14,14 @@ class EventRegisterView(CustomModelViewSet):
     model_class = EventRegister
     serializer_class = EventRegisterSerializer
     filterset_fields = {
-        'event_id': ['exact']
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'event_type': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
     }
 
     def perform_create(self, serializer):
