@@ -1,6 +1,7 @@
 from rest_framework.decorators import action
 from rest_framework.response import Response
 from bluedot_rest_framework import import_string
+from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet
 from bluedot_rest_framework.utils.func import orm_bulk_update
 
@@ -12,9 +13,14 @@ class EventSpeakerView(CustomModelViewSet):
     model_class = EventSpeaker
     serializer_class = EventSpeakerSerializer
     pagination_class = None
+    permission_classes = [IsAuthenticatedOrReadOnly]
 
     filterset_fields = {
-        'event_id': ['exact'],
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+
     }
 
     def create(self, request, *args, **kwargs):
