@@ -14,7 +14,10 @@ class EventVenueView(CustomModelViewSet):
     pagination_class = None
 
     filterset_fields = {
-        'event_id': ['exact']
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
     }
 
     def list(self, request, *args, **kwargs):
