@@ -1,6 +1,6 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from bluedot_rest_framework import import_string
-
+from rest_framework.serializers import CharField, IntegerField
 
 EventVote = import_string('EVENT.vote.models')
 EventVoteUser = import_string('EVENT.vote.user_models')
@@ -14,7 +14,11 @@ class EventVoteSerializer(CustomSerializer):
 
 
 class EventVoteUserSerializer(CustomSerializer):
+    user_id = IntegerField(required=False)
+    unionid = CharField(required=False)
+    openid = CharField(required=False)
+    wechat_id = IntegerField(required=False)
 
     class Meta:
         model = EventVoteUser
-        fileds = '__all__'
+        fields = '__all__'
