@@ -2,7 +2,7 @@ from django.db import models
 
 
 class AbstractUser(models.Model):
-    wechat_id = models.IntegerField()
+    wechat_id = models.IntegerField(null=True)
     unionid = models.CharField(max_length=100, null=True)
     openid = models.CharField(max_length=100, null=True)
 
