@@ -4,14 +4,13 @@ from rest_framework.decorators import action
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat, jwt_get_userinfo_handler
-from .frontend_views import FrontendView
 
 
 User = import_string('USER.models')
 UserSerializer = import_string('USER.serializers')
 
 
-class UserView(CustomModelViewSet, FrontendView):
+class UserView(CustomModelViewSet):
     model_class = User
     serializer_class = UserSerializer
 
