@@ -1,12 +1,13 @@
 import json
 from websocket import create_connection
 from django.http import HttpResponse
+from django.conf import settings
 from rest_framework.views import APIView
 from rest_framework.response import Response
 
 from bluedot_rest_framework.utils.oss import OSS
-from bluedot_rest_framework.wechat import OfficialAccount
-from bluedot_rest_framework.wechat.utils import create_auth_token
+from .. import OfficialAccount
+from ..handle import WeChatUserSet
 from bluedot_rest_framework import import_string
 
 from .models import WeChatLogin
@@ -37,9 +38,9 @@ class WeChatLoginWebSocketView(APIView):
         scene_str = request.query_params.get('scene_str', '')
         openid = request.query_params.get('openid', '')
         user_info = OfficialAccount.user.get(openid)
-        token = create_auth_token(user_info)
+        token = WeChatUserSet(user_info=user_info).get_token()
         ws = create_connection(
-            "ws://cpa-global-wechat.bluewebonline.com/ws/wechat/login/" + scene_str)
+            f"ws://{settings.ALLOWED_HOSTS[0]}/ws/wechat/login/" + scene_str)
         ws.send(json.dumps({'token': token}))
         ws.close()
         return Response({'token': token})
