@@ -7,11 +7,12 @@ from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
 from bluedot_rest_framework import import_string
-from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat
+from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat, jwt_get_wechatid_handler
 
 from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
-from .utils import create_auth_token
+from .handle import WeChatUserSet
 from .models import WeChatUser
+from .serializers import WeChatUserSerializer
 User = import_string('USER.models')
 
 
@@ -92,7 +93,7 @@ class OAuth(APIView):
                 referer_uri, 'snsapi_userinfo')
             wechat_oauth.fetch_access_token(code)
             user_info = wechat_oauth.get_user_info()
-            token = create_auth_token(user_info)
+            token = WeChatUserSet(user_info=user_info).get_token()
             return Response({'token': token})
         else:
             wechat_oauth = official_account_oauth(
@@ -101,17 +102,13 @@ class OAuth(APIView):
             return HttpResponseRedirect(url)
 
 
-class Token(APIView):
-    permission_classes = ()
+class Current(APIView):
 
-    def post(self, request, *args, **kwargs):
-        data = request.data
-        user_queryset = UesrModel.objects.filter(openid=data['openid']).first()
-        if user_queryset is None:
-            user_queryset = UesrModel.objects.create(**data)
-        token = jwt_create_token_wechat(
-            openid=user_queryset.openid, unionid=user_queryset.unionid, userid=str(user_queryset.pk))
-        return Response({'token': token})
+    def get(self, request, *args, **kwargs):
+        wechat_id = jwt_get_wechatid_handler(request.auth)
+        queryset = WeChatUser.objects.get(pk=wechat_id)
+        data = WeChatUserSerializer(queryset).data
+        return Response(data)
 
 
 class Menu(APIView):
